# ATTENTION

This package is renamed to "searchbible".

Please visit https://pypi.org/project/searchbible for all latest updates.

# searchbibleai
Integrate Unique Bible App resources with AI tools

Built upon our projects, the [UniqueBible App](https://github.com/eliranwong/UniqueBible) and [LetMeDoIt AI](https://github.com/eliranwong/letmedoit), SearchBible AI is our latest Bible app that aims to integrate our comprehensive Bible resources with the recent advancements in AI technology and tools.

# Installation / Upgrade

> pip install --upgrade searchbibleai

# Usage

> searchbibleai

To convert an UniqueBible App bible file, e.g.:

> searchbibleaiconvertor -b "/temp/NET.bible"

# Progress

1. Support conversion UnqiueBible App bibles (done)

2. Build simple cli interface for reading single bible chapter (partial)

3. Build simple cli interface for searching verses (partial)

4. Build simple cli interface for searching paragraphs (pending)

5. Integrates ChatGPT and Gemini Pro features (pending)

6. Support more UnqiueBible App bible resources (pending)

7. Build a Qt-based graphical user interface, like we do in [UniqueBible App](https://github.com/eliranwong/UniqueBible) (pending)